@@ -1,5 +1,5 @@
 package AnyEvent::Plurk;
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 use 5.008;
 use common::sense 2.02;
@@ -39,13 +39,11 @@ sub _tick {
         @{$self->{_plurk}->get_unread_plurks()};
 
     $self->event("unread_plurks" => \@unread_plurks);
-
-    AE::timer(60, 0, sub { $self->_tick });
 }
 
 sub start {
     my $self = shift;
-    $self->_tick;
+    $self->{_tick_timer} = AE::timer(0, 60, sub { $self->_tick });
 }
 
 1;
